should_push_notify

Function should_push_notify 

pub fn should_push_notify(action_type: &str, sub_type: Option<&str>) -> bool
Check if an action type should trigger push notifications

Returns true if the action type is configured to send push notifications when the user is offline.