Type definitions for the Action DSL
Structs
- Action
Definition - Complete action type definition in DSL format
- Action
Hooks - Lifecycle hooks for action processing
- Action
Metadata - Metadata about an action type
- Behavior
Flags - Behavior flags controlling action processing
- Coalesce
Expr - Coalesce expression (return first non-null value)
- Content
Schema - Schema definition for the content field
- Content
Schema Wrapper - Wrapper for content schema
- Field
Constraints - Field constraints - only optionality is configurable (types are fixed)
- Permission
Rules - Permission rules for action types
- Schema
Field - Schema field definition for object properties
- Ternary
Expr - Ternary expression (if-then-else)
Enums
- Arithmetic
Expr - Arithmetic expressions
- Comparison
Expr - Comparison expressions
- Content
Type - Content type
- Expression
- Expression - can be a literal, variable reference, or complex expression
- Field
Constraint - Field constraint - controls whether a field is required, forbidden, or optional
- Field
Type - Field type for schema properties
- Logical
Expr - Logical expressions
- Operation
- DSL operation - tagged enum for all operation types
- String
OpExpr - String operations
- Update
Value - Update value for action updates (supports increment/decrement)