pub fn get_push_setting_key(action_type: &str) -> &'static str
Get the push notification setting key for an action type
Returns the settings key to check whether push notifications are enabled for this action type.