pub fn should_push_notify(action_type: &str, sub_type: Option<&str>) -> boolExpand description
Check if an action type should trigger push notifications
Returns true if the action type is configured to send push notifications when the user is offline.